@@ -228,8 +228,15 @@ def upload_packed(ctx, import_request, packed):
     files = {
         'file': ('features_backup.rcdb', packed)
     }
+
+    if ctx.verbose:
+        click.echo("Sending the file to the S3 {}".format(destination))
+
     response = requests.post(destination['url'], data=destination['fields'], files=files)
     if response.status_code < 300:
+        if ctx.verbose:
+            click.echo("S3 {} response: {}".format(response.status_code, response.content))
+
         ctx.provider.notify_classification_database_import_done(
             id=import_request['id']
         )
@@ -248,14 +255,21 @@ def upload_packed(ctx, import_request, packed):
 @click.option('-f', '--features', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @pass_rebotics_context
 def pack_and_import_classification_db(ctx, retailer, model, images, labels, features):
-    """
-        Pack classification database to single .rcdb file and import it to the Rebotics Admin
+    """Pack classification database to single .rcdb file and import it to the Rebotics Admin
+
+\b
 db/
 ├── custom_folder
 │   ├── image_400x400_copy.png
 │   └── image_400x400.png
 ├── features.txt
 └── labels.txt
+
+    It is a single step command with equivalent of running two commands:
+
+admin pack-classification-db --features features.txt --labels labels.txt --images ./custom_folder/ --target classification.rcdb
+
+admin import_classification_db --retailer delta --model test_code classification.rcdb
     """
     packer = ClassificationDatabasePacker(destination=None)
     if ctx.verbose:
@@ -265,13 +279,22 @@ db/
                    "images: {images}".format(labels=labels, features=features, images=images))
     try:
         packed = packer.pack(labels, features, images)
+        packed.seek(0)
     except ClassificationDatabaseException as exc:
         raise click.ClickException(str(exc))
+
+    if ctx.verbose:
+        click.echo("Creating import request: \n"
+                   "retailer: {}\n"
+                   "model: {}\n"
+                   "extension: {}".format(retailer, model, packer.extension))
+
     import_request = ctx.provider.create_classification_database_import(
         retailer=retailer, model=model, extension=packer.extension
     )
     if ctx.verbose:
         click.echo("Import request: {}".format(import_request))
+
     upload_packed(ctx, import_request, packed)
 
 
@@ -281,13 +304,23 @@ db/
 @click.argument('filepath', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @pass_rebotics_context
 def import_classification_db(ctx, retailer, model, filepath):
-    """
-    Import rcdb file to Rebotics Admin
+    """Import rcdb file to Rebotics Admin. Example usage:
+
+    admin import_classification_db --retailer delta --model test_code classification.rcdb
+
     """
     extension = os.path.split(filepath)[-1].split('.')[-1]
+    if ctx.verbose:
+        click.echo("Creating import request: \n"
+                   "retailer: {}\n"
+                   "model: {}\n"
+                   "extension: {}".format(retailer, model, extension))
+
     import_request = ctx.provider.create_classification_database_import(
         retailer=retailer, model=model, extension=extension
     )
+    if ctx.verbose:
+        click.echo("Import request: {}".format(import_request))
     with open(filepath, 'rb') as packed:
         upload_packed(ctx, import_request, packed)
 
@@ -296,17 +329,22 @@ def import_classification_db(ctx, retailer, model, filepath):
 @click.option('-i', '--images', type=click.Path(exists=True, file_okay=False, dir_okay=True))
 @click.option('-l', '--labels', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @click.option('-f', '--features', type=click.Path(exists=True, file_okay=True, dir_okay=False))
-@click.option('-t', '--target', type=click.Path(exists=True, file_okay=True, dir_okay=True), default='.')
+@click.argument('target', type=click.Path(exists=False, file_okay=True, dir_okay=True), default='.')
 @pass_rebotics_context
 def pack_classification_db(ctx, images, labels, features, target):
-    """
-        Pack classification database to single .rcdb file
+    """Pack classification database to single .rcdb file
+
+\b
 db/
 ├── custom_folder
 │   ├── image_400x400_copy.png
 │   └── image_400x400.png
 ├── features.txt
 └── labels.txt
+
+    Example usage:
+        admin pack-classification-db --features features.txt --labels labels.txt --images ./custom_folder/ --target classification.rcdb
+
     """
     target = pathlib.Path(target)
     if target.is_dir():
