@@ -1,6 +1,6 @@
 import pathlib
 
-from rebotics_sdk.advanced.packers import ClassificationDatabasePacker
+from rebotics_sdk.advanced.packers import ClassificationDatabasePacker, ZipDatabasePacker
 
 
 def test_classification_packing():
@@ -32,3 +32,23 @@ def test_classification_packing():
 
     assert og_file.stat().st_size == tmp_file.stat().st_size
     tmp_file.unlink()
+
+
+def test_zip_packing():
+    packer = ZipDatabasePacker()
+    packed = packer.pack(
+        labels=[
+            '123123123'
+        ],
+        features=[
+            '123123123123123'
+        ]
+    )
+    assert packer.meta_data['count'] == 1
+
+    unpacker = ZipDatabasePacker(source=packed)
+    for entry in unpacker.unpack():
+        assert entry.label == '123123123'
+        assert entry.feature == '123123123123123'
+
+    assert unpacker.meta_data['count'] == 1
